Result
======

.. currentmodule:: pqp.refutation

.. autoclass:: Result
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Result.keys

   .. rubric:: Methods Summary

   .. autosummary::

      ~Result.explain
      ~Result.explain_all
      ~Result.get_dependencies
      ~Result.get_nested_dependencies

   .. rubric:: Attributes Documentation

   .. autoattribute:: keys

   .. rubric:: Methods Documentation

   .. automethod:: explain
   .. automethod:: explain_all
   .. automethod:: get_dependencies
   .. automethod:: get_nested_dependencies
